# IconDimensions

Provides the dimension of an icon. Can help to choose a specific icon to use depending on how large the display is, for example. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**width** | **int** | The width of the icon in pixels. | 
**height** | **int** | The height of the icon in pixels. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


